==> dash-bootstrap-components-0.12.2.tgz: package/src/components/nav/NavbarBrand.js <==
import React from 'react';
import PropTypes from 'prop-types';
import {omit} from 'ramda';
import {NavbarBrand as RSNavbarBrand} from 'reactstrap';
import Link from '../../private/Link';

/**
 * Call out attention to a brand name or site title within a navbar.
 */
const NavbarBrand = props => {
  const {children, loading_state, ...otherProps} = props;
  return (
    <RSNavbarBrand
      {...omit(['setProps'], otherProps)}
      tag={props.href ? Link : 'span'}
      data-dash-is-loading={
        (loading_state && loading_state.is_loading) || undefined
      }
    >
      {children}
    </RSNavbarBrand>
  );
};

NavbarBrand.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  id: PropTypes.string,

  /**
   * The children of this component
   */
  children: PropTypes.node,
  /**
   * Defines CSS styles which will override styles previously set.
   */
  style: PropTypes.object,

  /**
   * Often used with CSS to style elements with common properties.
   */
  className: PropTypes.string,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  key: PropTypes.string,

  /**
   * If true, the browser will treat this as an external link,
   * forcing a page refresh at the new location. If false,
   * this just changes the location without triggering a page
   * refresh. Use this if you are observing dcc.Location, for
   * instance. Defaults to true for absolute URLs and false
   * otherwise.
   */
  external_link: PropTypes.bool,

  /**
   * URL of the linked resource
   */
  href: PropTypes.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  loading_state: PropTypes.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: PropTypes.bool,
    /**
     * Holds which property is loading
     */
    prop_name: PropTypes.string,
    /**
     * Holds the name of the component that is loading
     */
    component_name: PropTypes.string
  })
};

export default NavbarBrand;

==> dash-bootstrap-components-1.6.0-rc1.tgz: package/src/components/nav/NavbarBrand.js <==
import React from 'react';
import PropTypes from 'prop-types';
import {omit} from 'ramda';
import RBNavbarBrand from 'react-bootstrap/NavbarBrand';
import Link from '../../private/Link';
import {sanitizeAndCheckUrl} from '../../private/util';

/**
 * Call out attention to a brand name or site title within a navbar.
 */
const NavbarBrand = props => {
  const {
    children,
    loading_state,
    className,
    class_name,
    href,
    setProps,
    ...otherProps
  } = props;
  const sanitizedUrl = sanitizeAndCheckUrl(href, setProps);
  return (
    <RBNavbarBrand
      className={class_name || className}
      {...otherProps}
      as={sanitizedUrl ? Link : 'span'}
      href={sanitizedUrl}
      data-dash-is-loading={
        (loading_state && loading_state.is_loading) || undefined
      }
    >
      {children}
    </RBNavbarBrand>
  );
};

NavbarBrand.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  id: PropTypes.string,

  /**
   * The children of this component
   */
  children: PropTypes.node,
  /**
   * Defines CSS styles which will override styles previously set.
   */
  style: PropTypes.object,

  /**
   * Often used with CSS to style elements with common properties.
   */
  class_name: PropTypes.string,

  /**
   * **DEPRECATED** Use `class_name` instead.
   *
   * Often used with CSS to style elements with common properties.
   */
  className: PropTypes.string,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  key: PropTypes.string,

  /**
   * If true, the browser will treat this as an external link,
   * forcing a page refresh at the new location. If false,
   * this just changes the location without triggering a page
   * refresh. Use this if you are observing dcc.Location, for
   * instance. Defaults to true for absolute URLs and false
   * otherwise.
   */
  external_link: PropTypes.bool,

  /**
   * URL of the linked resource
   */
  href: PropTypes.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  loading_state: PropTypes.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: PropTypes.bool,
    /**
     * Holds which property is loading
     */
    prop_name: PropTypes.string,
    /**
     * Holds the name of the component that is loading
     */
    component_name: PropTypes.string
  })
};

export default NavbarBrand;
